@@ -1,5 +1,6 @@
 .onLoad <- function(libname, pkgname) {
   modules <- paste0("stan_fit4", names(stanmodels), "_mod")
-  for (m in modules)
+  for (m in modules) {
       loadModule(m, what = TRUE)
+  }
 }
