@@ -36,12 +36,17 @@ rst_cl
 oa_cl <- psrwe_outana(rst_cl, method_ci = "wilson", mu = 0.40)
 oa_cl
 
-### Use optmatch with caliper
-dta_ps_match_opt <- psrwe_match(dta_ps_single, ratio = 2, strata_covs = "V2",
-                                mat_method = "optm", caliper = 0.5)
-ps_bor_match_opt <- psrwe_borrow(dta_ps_match_opt, total_borrow = 30)
-rst_cl_opt <- psrwe_compl(ps_bor_match_opt,
-                          outcome_type = "binary",
-                          v_outcome    = "Y_Bin")
-rst_cl_opt
-
+### Use optmatch with caliper.
+.remark_optmatch <- function() {
+    warning("The optmatch may restrict use (academic license).")
+    dta_ps_match_opt <- psrwe_match(dta_ps_single, ratio = 2,
+                                    strata_covs = "V2",
+                                    mat_method = "optm", caliper = 0.5)
+    ps_bor_match_opt <- psrwe_borrow(dta_ps_match_opt, total_borrow = 30)
+    rst_cl_opt <- psrwe_compl(ps_bor_match_opt,
+                              outcome_type = "binary",
+                              v_outcome    = "Y_Bin")
+    rst_cl_opt
+}
+### Unmark below to run if optmatch is available.
+# .remark_optmatch()
